==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/DiagnosticsRefArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Reference to sinks in DiagnosticsDescription.
 * @property enabled Status of whether or not sinks are enabled.
 * @property sinkRefs List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
 */
public data class DiagnosticsRefArgs(
    public val enabled: Output<Boolean>? = null,
    public val sinkRefs: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .sinkRefs(sinkRefs?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DiagnosticsRefArgs].
 */
@PulumiTagMarker
public class DiagnosticsRefArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var sinkRefs: Output<List<String>>? = null

    /**
     * @param value Status of whether or not sinks are enabled.
     */
    @JvmName("idribxioieekgmvv")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("lpwrmlwbqdidygch")
    public suspend fun sinkRefs(`value`: Output<List<String>>) {
        this.sinkRefs = value
    }

    @JvmName("nqvbubjevtvbrtum")
    public suspend fun sinkRefs(vararg values: Output<String>) {
        this.sinkRefs = Output.all(values.asList())
    }

    /**
     * @param values List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("peabggpvdqvqnmqg")
    public suspend fun sinkRefs(values: List<Output<String>>) {
        this.sinkRefs = Output.all(values)
    }

    /**
     * @param value Status of whether or not sinks are enabled.
     */
    @JvmName("rprjtnenjccpikrh")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("tybvqtqihnoacqlp")
    public suspend fun sinkRefs(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sinkRefs = mapped
    }

    /**
     * @param values List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("xyrbqhrnqxpohdvt")
    public suspend fun sinkRefs(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sinkRefs = mapped
    }

    internal fun build(): DiagnosticsRefArgs = DiagnosticsRefArgs(
        enabled = enabled,
        sinkRefs = sinkRefs,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/DiagnosticsRefArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Reference to sinks in DiagnosticsDescription.
 * @property enabled Status of whether or not sinks are enabled.
 * @property sinkRefs List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
 */
public data class DiagnosticsRefArgs(
    public val enabled: Output<Boolean>? = null,
    public val sinkRefs: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.DiagnosticsRefArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .sinkRefs(sinkRefs?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DiagnosticsRefArgs].
 */
@PulumiTagMarker
public class DiagnosticsRefArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var sinkRefs: Output<List<String>>? = null

    /**
     * @param value Status of whether or not sinks are enabled.
     */
    @JvmName("irqgxgffcqygmcsk")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("piadscjjesarypwt")
    public suspend fun sinkRefs(`value`: Output<List<String>>) {
        this.sinkRefs = value
    }

    @JvmName("ybgiujqthxtwyndh")
    public suspend fun sinkRefs(vararg values: Output<String>) {
        this.sinkRefs = Output.all(values.asList())
    }

    /**
     * @param values List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("xkvsnixvxikrtxmq")
    public suspend fun sinkRefs(values: List<Output<String>>) {
        this.sinkRefs = Output.all(values)
    }

    /**
     * @param value Status of whether or not sinks are enabled.
     */
    @JvmName("fpfwpudwouyxydlt")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("veepyrxsfijofptc")
    public suspend fun sinkRefs(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sinkRefs = mapped
    }

    /**
     * @param values List of sinks to be used if enabled. References the list of sinks in DiagnosticsDescription.
     */
    @JvmName("tmwtgfxpvdasfych")
    public suspend fun sinkRefs(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sinkRefs = mapped
    }

    internal fun build(): DiagnosticsRefArgs = DiagnosticsRefArgs(
        enabled = enabled,
        sinkRefs = sinkRefs,
    )
}
